// Morphometric Minowski Numerical Analysis 
#include "binnedskymap.h"
#include "phasespace.h"

static std::string config_file = "minkmap.conf";
static std::string prefix_if = "input/";
static std::string prefix_of = "output/";
static std::string countratefilename = "no_filename";
static unsigned Nx = 100;
static unsigned Ny = Nx;
static double xmin = -1;
static double xmax = 1;
static double ymin = xmin;
static double ymax = xmax;
static double lambda = 5;
static double k_src = 0;
static std::string functionals = "APC";
static unsigned slide = 15;
static unsigned A_blackpix = 0;
static bool mbc = false;
static bool pix = false;
static bool verbose = true;
static unsigned seed = 17;
static unsigned seedsub = 23;

int main(int clc, char* clv[]){
  // Read in parameters
  intialize(clc, clv, config_file, prefix_if, prefix_of, countratefilename,
	    Nx, Ny, xmin, xmax, ymin, ymax, lambda, k_src, functionals, slide, A_blackpix, mbc, pix, verbose,
	    seed, seedsub);
  
  BinnedSkyMap skylab(Nx,Ny,xmin,xmax,ymin,ymax,prefix_if,prefix_of,seed,seedsub);
  skylab.add_bck_intensity(lambda);
  
  std::vector<unsigned> multipl=stdvector<unsigned>(3,4,5,6);
  std::vector<double> sigma_x=stdvector<double>(3,0.3,0.5,0.6);
  std::vector<double> sigma_y=stdvector<double>(3,0.2,0.2,0.25);
  
  for(unsigned theta=1; theta <= 7; theta++){
    double phi=theta*45-30;
    phi*=M_PI/180;
    k_src*=pow(theta,0.04);
    for(unsigned i=1; i<=3; i++){
      std::cout << theta*45 << "  " << i << std::endl;
      double mu_x=multipl[i-1]*cos(theta*0.25*M_PI)*i;
      double mu_y=multipl[i-1]*sin(theta*0.25*M_PI)*i;
      Gaussian source(mu_x,mu_y,sigma_x[i-1],sigma_y[i-1],phi);
      skylab.add_src_intensity(pow(sigma_x[i-1]*sigma_y[i-1],0.5)*k_src,source);
    }
  }
  
  int N_runs = 100;
  
  skylab.plot_intensity("intensity-profile");
  skylab.simulate_countrate();
  skylab.plot_countrate("counts-map");
  
  for(int run=0;run<N_runs;run++){
    std::cout << "run " << run << " of 0 ... " << N_runs-1 << std::endl;
    skylab.simulate_countrate();
    
    std::stringstream joint;
    joint << "minkowski-map-joint-run-" << run;
    skylab.Minkowski_sky_map_APC_pix_wbc(lambda, slide, verbose, true, true, joint);

    std::stringstream simple;
    simple << "minkowski-map-simple-run-" << run;
    skylab.Minkowski_sky_map_A_pix_wbc(lambda, slide, verbose, simple);
  }
  
  return 0;
}
